@@ -98,6 +98,7 @@ class VirtualAccount(VirtualAccountBase):
     status: str
     created_at: Optional[Union[None, str]]
     updated_at: Optional[Union[None, str]]
+    user_external_id: str
 
 
 class BankAccountBase(BaseModel):
@@ -329,3 +330,28 @@ class BatchTransaction(BaseModel):
     currency: str
     debit_credit: str
     description: str
+
+
+class BPayDetailsBase(BaseModel):
+    account_name: str
+    biller_code: int
+
+
+class BPayDetails(BPayDetailsBase):
+    biller_name: str
+    crn: int
+
+
+class BPayAccount(BaseModel):
+    id: str
+    active: bool
+    created_at: str
+    updated_at: str
+    verification_status: str
+    currency: str
+    bpay_details: BPayDetails
+
+
+class BPayAccountRequest(BPayDetailsBase):
+    user_id: str
+    biller_crn: int
